==> diff-impl-192.6603.28-sources.jar: com/intellij/diff/applications/DiffApplication.java <==
/*
 * Copyright 2000-2015 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.diff.applications;

import com.intellij.diff.DiffDialogHints;
import com.intellij.diff.DiffManagerEx;
import com.intellij.diff.DiffRequestFactory;
import com.intellij.diff.chains.SimpleDiffRequestChain;
import com.intellij.diff.requests.DiffRequest;
import com.intellij.diff.util.DiffPlaces;
import com.intellij.diff.util.DiffUserDataKeys;
import com.intellij.ide.CliResult;
import com.intellij.openapi.application.ApplicationNamesInfo;
import com.intellij.openapi.diff.DiffBundle;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.ui.WindowWrapper;
import com.intellij.openapi.vfs.VirtualFile;
import com.intellij.util.ui.UIUtil;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.Arrays;
import java.util.List;
import java.util.concurrent.CompletableFuture;
import java.util.concurrent.Future;

public class DiffApplication extends DiffApplicationBase {
  public DiffApplication() {
    super("diff", 2, 3);
  }

  @NotNull
  @Override
  public String getUsageMessage() {
    final String scriptName = ApplicationNamesInfo.getInstance().getScriptName();
    return DiffBundle.message("diff.application.usage.parameters.and.description", scriptName);
  }

  @NotNull
  @Override
  public Future<CliResult> processCommand(@NotNull String[] args, @Nullable String currentDirectory) throws Exception {
    List<String> filePaths = Arrays.asList(args).subList(1, args.length);
    List<VirtualFile> files = findFiles(filePaths, currentDirectory);
    Project project = guessProject(files);

    DiffRequest request;
    if (files.size() == 3) {
      files = replaceNullsWithEmptyFile(files);
      request = DiffRequestFactory.getInstance().createFromFiles(project, files.get(0), files.get(2), files.get(1));
    }
    else {
      request = DiffRequestFactory.getInstance().createFromFiles(project, files.get(0), files.get(1));
    }

    SimpleDiffRequestChain chain = new SimpleDiffRequestChain(request);
    chain.putUserData(DiffUserDataKeys.PLACE, DiffPlaces.EXTERNAL);

    if (project != null) {
      CompletableFuture<CliResult> future = new CompletableFuture<>();
      Runnable resultCallback = () -> future.complete(new CliResult(0, null));

      DiffDialogHints dialogHints = new DiffDialogHints(WindowWrapper.Mode.FRAME, null,
                                                        wrapper -> UIUtil.runWhenWindowClosed(wrapper.getWindow(), resultCallback));
      DiffManagerEx.getInstance().showDiffBuiltin(project, chain, dialogHints);
      return future;
    }
    else {
      DiffManagerEx.getInstance().showDiffBuiltin(null, chain, DiffDialogHints.MODAL);
      return CliResult.ok();
    }
  }
}

==> diff-impl-193.6494.30-sources.jar: com/intellij/diff/applications/DiffApplication.java <==
// Copyright 2000-2019 JetBrains s.r.o. Use of this source code is governed by the Apache 2.0 license that can be found in the LICENSE file.
package com.intellij.diff.applications;

import com.intellij.diff.DiffDialogHints;
import com.intellij.diff.DiffManagerEx;
import com.intellij.diff.DiffRequestFactory;
import com.intellij.diff.chains.SimpleDiffRequestChain;
import com.intellij.diff.requests.DiffRequest;
import com.intellij.diff.util.DiffPlaces;
import com.intellij.diff.util.DiffUserDataKeys;
import com.intellij.ide.CliResult;
import com.intellij.openapi.application.ApplicationNamesInfo;
import com.intellij.openapi.diff.DiffBundle;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.ui.WindowWrapper;
import com.intellij.openapi.vfs.VirtualFile;
import com.intellij.util.ui.UIUtil;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.List;
import java.util.concurrent.CompletableFuture;
import java.util.concurrent.Future;

final class DiffApplication extends DiffApplicationBase {
  DiffApplication() {
    super("diff", 2, 3);
  }

  @NotNull
  @Override
  public String getUsageMessage() {
    final String scriptName = ApplicationNamesInfo.getInstance().getScriptName();
    return DiffBundle.message("diff.application.usage.parameters.and.description", scriptName);
  }

  @NotNull
  @Override
  public Future<CliResult> processCommand(@NotNull List<String> args, @Nullable String currentDirectory) throws Exception {
    List<String> filePaths = args.subList(1, args.size());
    List<VirtualFile> files = findFiles(filePaths, currentDirectory);
    Project project = guessProject(files);

    DiffRequest request;
    if (files.size() == 3) {
      files = replaceNullsWithEmptyFile(files);
      request = DiffRequestFactory.getInstance().createFromFiles(project, files.get(0), files.get(2), files.get(1));
    }
    else {
      request = DiffRequestFactory.getInstance().createFromFiles(project, files.get(0), files.get(1));
    }

    SimpleDiffRequestChain chain = new SimpleDiffRequestChain(request);
    chain.putUserData(DiffUserDataKeys.PLACE, DiffPlaces.EXTERNAL);

    if (project != null) {
      CompletableFuture<CliResult> future = new CompletableFuture<>();
      Runnable resultCallback = () -> future.complete(CliResult.OK);
      DiffDialogHints dialogHints = new DiffDialogHints(
        WindowWrapper.Mode.FRAME, null, wrapper -> UIUtil.runWhenWindowClosed(wrapper.getWindow(), resultCallback));
      DiffManagerEx.getInstance().showDiffBuiltin(project, chain, dialogHints);
      return future;
    }
    else {
      DiffManagerEx.getInstance().showDiffBuiltin(null, chain, DiffDialogHints.MODAL);
      return CliResult.OK_FUTURE;
    }
  }
}
